{
  description = "tacocat's nix configuration";

  nixConfig = {
    experimental-features = ["nix-command" "flakes"];
    extra-substituters = [
      # Nix community's cache server
      "https://nix-community.cachix.org"
      "https://helix.cachix.org"
    ];
    extra-trusted-public-keys = [
      "nix-community.cachix.org-1:mB9FSh9qf2dCimDSUo8Zy7bkq5CX+/rkCWyvRCYg3Fs="
      "helix.cachix.org-1:ejp9KQpR1FBI2onstMQ34yogDm4OgU2ru6lIwPvuCVs="
    ];
  };

  inputs = {
    nixpkgs.url = "github:nixos/nixpkgs/nixos-unstable";
    helix.url = "github:helix-editor/helix/master";
    home-manager = {
      url = "github:nix-community/home-manager";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    nixos-hardware.url = "github:NixOs/nixos-hardware/master";
    nur.url = "github:nix-community/nur";
  };

  # pass in the urls defined above
  # the @ syntax stores the arguments in the inputs variable
  outputs = {
    self,
    nixpkgs,
    home-manager,
    helix,
    nixos-hardware,
    nur,
    ...
  } @ inputs: let
    system = "x86_64-linux";
    pkgs = inputs.nixpkgs.legacyPackages.${system};
    overlays = [
      nur.overlay
    ];
    home-manager-config = toplevel: [
      home-manager.nixosModules.home-manager
      {
        home-manager.useGlobalPkgs = true;
        home-manager.extraSpecialArgs = {inherit inputs;};
        home-manager.users.tacocat = {
          imports = [toplevel];
          _module.args.theme = import ./modules/themes;
        };
      }
    ];
  in {
    # desktop
    nixosConfigurations."BICEP" = nixpkgs.lib.nixosSystem {
      inherit system;
      specialArgs = {inherit inputs;};
      modules =
        [
          ./hosts/BICEP/configuration.nix
          ./modules/nixos-common.nix
          {nixpkgs.overlays = overlays;}
        ]
        ++ home-manager-config ./users/tacocat/home.nix;
    };

    # laptop
    nixosConfigurations."JWST" = nixpkgs.lib.nixosSystem {
      inherit system;
      specialArgs = {inherit inputs;};
      modules =
        [
          ./hosts/JWST/configuration.nix
          ./modules/nixos-common.nix
          nixos-hardware.nixosModules.dell-xps-15-9520
          {nixpkgs.overlays = overlays;}
        ]
        ++ home-manager-config ./users/tacocat/home.nix;
    };

    formatter.${system} = pkgs.alejandra;
  };
}
