{
  pkgs,
  theme,
  ...
}: {
  programs.firefox = {
    enable = true;
    policies = {
      DisableAppUpdate = true;
      DisableFirefoxAccounts = false;
      DisableFirefoxStudies = true;
      DisablePocket = true;
      DisableTelemetry = true;
      DontCheckDefaultBrowser = true;
      EnableTrackingProtection = true;
      NoDefaultBookmarks = true;
      OfferToSaveLogins = false;
      OfferToSaveLoginsDefault = false;
      PasswordManagerEnabled = false;
      FirefoxHome = {
        Search = true;
        Pocket = false;
        Snippets = false;
        TopSites = false;
        Highlights = false;
      };
      UserMessaging = {
        ExtensionRecommendations = false;
        SkipOnboarding = true;
      };
      Cookies = {
        ExpireAtSessionEnd = true;
        RejectTracker = true;
      };
      SanitizeOnShutdown = {
        Cache = true;
        Cookies = true;
        Downloads = true;
        FormData = true;
        SiteSettings = true;
        History = false;
      };
    };
    profiles = {
      "aria" = {
        extensions = with pkgs.nur.repos.rycee.firefox-addons; [
          ublock-origin
          bitwarden
          canvasblocker
          aria2-integration
          sponsorblock
          xbrowsersync
          sidebery
        ];
        settings = {
          "browser.aboutConfig.showWarning" = false;
          "browser.startup.page" = 1;
          "geo.provider.network.url" = "https://location.services.mozilla.com/v1/geolocate?key=%MOZILLA_API_KEY%";
          "intl.accept_languages" = "en-US, en";
          "app.update.auto" = false;
          "browser.download.useDownloadDir" = false;
          "browser.download.manager.addToRecentDocs" = false;
          "browser.urlbar.suggest.addons" = false;
          "browser.urlbar.suggest.clipboard" = false;
          "browser.urlbar.suggest.engines" = false;
          "browser.urlbar.suggest.history" = false;
          "browser.urlbar.suggest.pocket" = false;
          "browser.urlbar.suggest.topsites" = false;
          "browser.urlbar.suggest.searches" = false;
          "browser.urlbar.suggest.trending" = false;
          "browser.tabs.firefox-view" = false;
          "toolkit.legacyUserProfileCustomizations.stylesheets" = true;
          "browser.toolbars.bookmarks.visibility" = "never";
          "extensions.activeThemeID" = "firefox-compact-dark@mozilla.org";
        };
        search = {
          force = true;
          default = "Catgirl";
          engines = {
            "Nix Packages" = {
              urls = [
                {
                  template = "https://search.nixos.org/packages";
                  params = [
                    {
                      name = "type";
                      value = "packages";
                    }
                    {
                      name = "channel";
                      value = "unstable";
                    }
                    {
                      name = "query";
                      value = "{searchTerms}";
                    }
                  ];
                }
              ];
              icon = "${pkgs.nixos-icons}/share/icons/hicolor/scalable/apps/nix-snowflake.svg";
              definedAliases = ["@np"];
            };
            "Celtic Lite" = {
              urls = [
                {
                  template = "https://search.celticlite.com/search";
                  params = [
                    {
                      name = "q";
                      value = "{searchTerms}";
                    }
                  ];
                }
              ];
              definedAliases = ["@cl"];
            };
            "Catgirl" = {
              urls = [
                {
                  template = "https://sx.catgirl.cloud/search";
                  params = [
                    {
                      name = "q";
                      value = "{searchTerms}";
                    }
                  ];
                }
              ];
              definedAliases = ["@cg"];
            };
            "Google".metaData.hidden = true;
            "Amazon.com".metaData.hidden = true;
            "Bing".metaData.hidden = true;
            "eBay".metaData.hidden = true;
          };
        };
        userChrome = ''
          @namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");
          * {
              font-family: "Inter" !important;
              font-size: 14px !important;

              --arrowpanel-background: ${theme.base00} !important;
              --arrowpanel-border-color: ${theme.base02} !important;
              --autocomplete-popup-highlight-color: ${theme.base02} !important;
              --autocomplete-popup-highlight-background: ${theme.base06} !important;
              --toolbarbutton-active-background: ${theme.base06} !important;
              --lwt-toolbarbutton-icon-fill-attention: var(--button-primary-bgcolor, ${theme.base06}) !important;
              --toolbar-field-focus-border-color: ${theme.base06} !important;
          }
          .toolbar {
              background-color: #11171D !important;
          }
          window,
          #main-window,
          #toolbar-menubar,
          #TabsToolbar,
          #PersonalToolbar,
          #navigator-toolbox,
          #sidebar-box {
              background-color: ${theme.base02} !important;
          }
          .tab-background[selected="true"] {
              background-color: ${theme.base00} !important;
          }
          .tab-background {
              background-color: ${theme.base02} !important;
          }
          .tabbrowser-tab:hover .tab-background {
              background-color: ${theme.base09} !important;
          }
          #urlbar {
              background-color: #11171D !important;
              border-radius: 10px !important;
          }
          #nav-bar {
              background-color: ${theme.base02} !important;
          }
          #firefox-view-button {
            visibility: collapse;
          }
          #alltabs-button {
            visibility: collapse;
          }
          #mainPopupSet menupopup,
          menupopup:not(.in-menulist) > menuitem,
          menupopup:not(.in-menulist) > menu {
              border: 0 !important;
              border-radius: 0px !important;
              padding: 0px 0px 0px 0px  !important;
          }
          /*
          */
          #back-button>.toolbarbutton-icon {
            transform: scale(.85, .85) !important;
            animation: none !important;
            border: none !important;
            box-shadow: none !important;
          }
          #back-button:not(:hover),
          #back-button:not(:hover) > .toolbarbutton-icon {
              background: none !important;
          }
          #back-button:hover,
          #back-button:hover > .toolbarbutton-icon {
              border-radius: 2px !important;
          }
          #whats-new-menu-button,
          #pocket-button,
          #save-to-pocket-button
          #reader-mode-button {
              display: none !important;
          }
          #star-button {
              color: ${theme.base06} !important;
          }
          #save-to-pocket-button {
              visibility: hidden !important;
          }
          #urlbar-input {
              background-color: ${theme.base00} !important;
              padding-left: 5px !important;
          }
          #urlbar-results {
              background-color: ${theme.base00} !important;
              border-radius: 5px !important;
          }
          #urlbar-results .urlbarView-row:hover{
              color: ${theme.base06} !important;
              border-radius: 5px !important;
          }
          .urlbarView-row[selected] .urlbarView-row-inner {
              border-radius: 5px !important;
              background-color: ${theme.base06} !important;
              color: ${theme.base00} !important;
          }
          #urlbar ::-moz-selection,
          .searchbar-textbox ::-moz-selection {
              background-color: ${theme.base01} !important;
              color: ${theme.base09} !important;
          }
          #tabbrowser-tabpanels {
              background-color: ${theme.base01} !important;
          }
          urlbar > #urlbar-background {
              background-color: ${theme.base00} !important;
          }
          #urlbar-background {
              background-color: ${theme.base00} !important;
              color: ${theme.base02} !important;
              border: 1px solid ${theme.base06} !important;
          }
          #urlbar-background:not([focused]) {
              background-color: ${theme.base00} !important;
              color: ${theme.base02} !important;
          }
          #urlbar-one-offs-header-label{
              display: none;
          }
          .search-one-offs > .search-panel-one-offs-header::before{
              display: block;
              content: "Search With:";
              padding-inline: var(--urlbarView-item-inline-padding) 18px;
              opacity: 0.6;
          }
          #tabbrowser-tabs {
          border-inline-start: none !important;
          }

          }
        '';
        userContent = ''
          @namespace url("http://www.w3.org/1999/xhtml");
          :root {
              scrollbar-color: ${theme.base00} ${theme.base02};
          }
          * {
              scrollbar-width: thin;
          }
          @-moz-document url-prefix("about:") {
              :root {
                  --in-content-page-background: ${theme.base00} !important;
                  --toolbar-field-focus-border-color: ${theme.base06} !important;
                  --toolbarbutton-active-background: ${theme.base06} !important;
              }
          }
          @-moz-document url("about:newtab"), url("about:home") {
              * {
                  font-family: "Inter" !important;
              }
              body {
                  background-color: ${theme.base00} !important;
              }
              .logo-and-wordmark {
                  display: none !important;
              }
              .SnippetBaseContainer {
                  display: none !important;
              }
              .search-handoff-button {
                  border-radius: 15px !important;
                  border-width: 4px !important;
                  border-color: ${theme.base02} !important;
                  background-size: 0px !important;
                  background-color: ${theme.base00} !important;
                  padding-inline-start: 10px !important;
                  padding-inline-end: 10px !important;
              }
              .icon-settings {
                  display: none !important;
              }
              .fake-textbox {
                  text-align: center !important;
              }
              .search-wrapper input {
                  background-color: ${theme.base09} !important;
                  border-radius: 0px !important;
                  background-image: none !important;
                  background-size: none !important;
                  text-align: center !important;
                  font-size: 17px !important;
                  padding-inline-start: 10px !important;
                  padding-inline-end: 10px !important;
              }
              .search-wrapper input:focus {
                  text-align: left !important;
              }
              .body-wrapper {
                  display: none !important;
              }
          }
        '';
      };
    };
  };
}
